@@ -1,6 +1,7 @@
 from gevent import monkey; monkey.patch_all()
 import logging
 import click
+import sys
 
 from .repo import Repo
 
@@ -66,6 +67,23 @@ def topology(repo, dotfile):
 
     click.echo("Done. You can run `dot {0}  -Tsvg -o {0}.svg` to convert it to SVG.".format(dotfile))
 
+
+@main.command()
+@pass_repo
+@click.option('--zookeeper', default='127.0.0.1')
+@click.option('--partitions', default=1)
+@click.option('--replication-factor', default=1)
+def create_topics(repo, zookeeper, partitions, replication_factor):
+    topics = set()
+
+    for task in [repo.load_task(x) for x in repo.tasks()]:
+        topics.update(task.source_topics)
+        topics.update(task.result_topics)
+
+    print >>sys.stderr, "Please run following commands to create topics:"
+    for topic in sorted(topics):
+        print "./bin/kafka-topics.sh --zookeeper {zookeeper} --create --topic {topic} --replication-factor {replication_factor} --partitions {partitions}".format(**locals())
+
 @main.command()
 @click.argument('task_name')
 def reset(task_name):
